<?php

namespace Litecms\Review\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Review\Interfaces\ReviewsRepositoryInterface;

class ReviewsPublicController extends BaseController
{
    // use ReviewsWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\Reviews\Interfaces\ReviewsRepositoryInterface $reviews
     *
     * @return type
     */
    public function __construct(ReviewsRepositoryInterface $reviews)
    {
        $this->repository = $reviews;
        parent::__construct();
    }

    /**
     * Show reviews's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $reviews = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('$review::reviews.names'))
            ->view('review::reviews.index')
            ->data(compact('reviews'))
            ->output();
    }


    /**
     * Show reviews.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $reviews = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($$reviews->name . trans('review::reviews.name'))
            ->view('review::reviews.show')
            ->data(compact('reviews'))
            ->output();
    }

}
